using AutoMapper;
using ldap_cesi.DTOs;
using ldap_cesi.DTOs.Inputs.Role;
using ldap_cesi.DTOs.Inputs.Salarie;
using ldap_cesi.DTOs.Inputs.Service;
using ldap_cesi.DTOs.Inputs.Site;
using ldap_cesi.DTOs.Outputs.Salarie;
using ldap_cesi.DTOs.Outputs.Service;
using ldap_cesi.DTOs.Outputs.Utilisateur;
using ldap_cesi.Entities;

namespace ldap_cesi.Mapper;

public class AutoMapperProfile : Profile
{
    public AutoMapperProfile()
    {
        // INPUTS MAPPER 
        CreateMap<ServiceCreateDto, Service>();
        CreateMap<ServiceUpdateDto, Service>();
        CreateMap<SiteCreateDto, Site>();
        CreateMap<RoleCreateDto, Role>();
        CreateMap<SiteUpdateDto, Site>();
        CreateMap<SalarieCreateDto, Salarie>()
            .ForMember(dest => dest.TelephoneFixe, opt => opt.MapFrom(src => src.TelephoneFixe))
            .ForMember(dest => dest.TelephonePortable, opt => opt.MapFrom(src => src.TelephonePortable));
        CreateMap<SalarieUpdateDto, Salarie>()
            .ForMember(dest => dest.TelephoneFixe, opt => opt.MapFrom(src => src.TelephoneFixe))
            .ForMember(dest => dest.TelephonePortable, opt => opt.MapFrom(src => src.TelephonePortable));
        
        
        //OUTPUTS MAPPER
        CreateMap<Utilisateur, UtilisateurOutputDto>()
            .ForMember(dest => dest.RoleNom, opt => opt.MapFrom(src => src.IdRoleNavigation.Nom));
        CreateMap<Salarie, SalarieDto>()
            .ForMember(dest => dest.Service, opt => opt.MapFrom(src => src.IdServiceNavigation))
            .ForMember(dest => dest.Site, opt => opt.MapFrom(src => src.IdSiteNavigation));
        CreateMap<Salarie, SalarieOutputDetail>()
            .ForMember(dest => dest.Service, opt => opt.MapFrom(src => src.IdServiceNavigation))
            .ForMember(dest => dest.Site, opt => opt.MapFrom(src => src.IdSiteNavigation));
        CreateMap<Service, ServiceDto>();
        CreateMap<Service, ServiceMinimalDto>();
        CreateMap<Site, SiteMinimalDto>();
        CreateMap<Site, SiteDto>()
            .ForMember(dest => dest.Salaries, opt => opt.MapFrom(src => src.Salaries));
        CreateMap<Salarie, SalarieListDto>()
            .ForMember(dest => dest.Service, opt => opt.MapFrom(src => src.IdServiceNavigation))
            .ForMember(dest => dest.Site, opt => opt.MapFrom(src => src.IdSiteNavigation));
        CreateMap<Service, ServiceDto>();
        CreateMap<Salarie, SalarieMinimalDto>();
        CreateMap<Salarie, SalarieListDto>()
            .ForMember(dest => dest.Service, opt => opt.MapFrom(src => src.IdServiceNavigation.Nom))
            .ForMember(dest => dest.Site, opt => opt.MapFrom(src => src.IdSiteNavigation.Ville));
    }
}