using ldap_cesi.Configurations;
using ldap_cesi.Context;
using ldap_cesi.Seeders;

var builder = WebApplication.CreateBuilder(args);
builder.BuildConf();
var app = builder.Build();

// Configure the HTTP request pipeline.
if (app.Environment.IsDevelopment())
{
    app.UseSwagger();
    app.UseSwaggerUI();
    
    app.Use(async (context, next) =>
    {
        if (context.Request.Path == "/")
        {
            context.Response.Redirect("/swagger");
            return;
        }
        await next();
    });
}

using (var scope = app.Services.CreateScope())
{
    var services = scope.ServiceProvider;
    var context = services.GetRequiredService<PgContext>();
    var seeder = new Seeders(context);
    
    if (app.Environment.IsDevelopment())
    {
        await seeder.GenerateSalaries(500);
    }
}

app.UseHttpsRedirection();
app.UseRouting();
app.UseCors("AllowAll");
app.UseAuthentication();
app.UseAuthorization();
app.MapControllers();
app.Run();
