using Bogus;
using ldap_cesi.Context;
using ldap_cesi.Entities;
using Microsoft.EntityFrameworkCore;

namespace ldap_cesi.Seeders;

public class Seeders
{
    private readonly PgContext _context;

    public Seeders(PgContext context)
    {
        _context = context;
    }

    public async Task GenerateSalaries(int count = 1000)
    {
        
        if (await _context.Salaries.AnyAsync())
        {
            Console.WriteLine("Des salariés existent déjà dans la base de données. Aucune donnée insérée.");
            return;
        }
        
        var salarieFaker = new Faker<Salarie>("fr")
            .RuleFor(s => s.Nom, f => f.Name.LastName())
            .RuleFor(s => s.Prenom, f => f.Name.FirstName())
            .RuleFor(s => s.TelephoneFixe, f => f.Phone.PhoneNumber())
            .RuleFor(s => s.TelephonePortable, f => f.Phone.PhoneNumber())
            .RuleFor(s => s.Email, (f, s) => f.Internet.Email(s.Prenom, s.Nom));

        var salaries = salarieFaker.Generate(count);

        // on s'assure que les relations (Service, Site) existent avant d'ajouter les salariés
        var services = await _context.Services.ToListAsync();
        var sites = await _context.Sites.ToListAsync();

        var random = new Random();
        foreach (var salarie in salaries)
        {
            salarie.IdServiceNavigation = services[random.Next(services.Count)];
            salarie.IdSiteNavigation = sites[random.Next(sites.Count)];
        }

        await _context.Salaries.AddRangeAsync(salaries);
        await _context.SaveChangesAsync();
    }
}