using FluentValidation;
using ldap_cesi.DTOs.Inputs.Service;

namespace ldap_cesi.Validator.Salarie;

public class SalarieUpdateValidator : AbstractValidator<SalarieUpdateDto>
{
    public SalarieUpdateValidator()
    {
        RuleFor(x => x.Id)
            .NotEmpty().WithMessage("L'identifiant du salarié est requis.");
        RuleFor(x => x.Nom)
            .NotEmpty().WithMessage("Le nom est requis.")
            .MaximumLength(50).WithMessage("Le nom ne doit pas dépasser 50 caractères.");

        RuleFor(x => x.Prenom)
            .NotEmpty().WithMessage("Le prénom est requis.")
            .MaximumLength(50).WithMessage("Le prénom ne doit pas dépasser 50 caractères.");

        RuleFor(x => x.TelephoneFixe)
            .NotEmpty().WithMessage("Le téléphone fixe est requis.")       
            .Matches(@"^(\+33|0)[1-9](\d{2}){4}$")
            .WithMessage("Le numéro de téléphone fixe n'est pas valide. Format attendu : +33XXXXXXXXX ou 0XXXXXXXXX.")
            .MaximumLength(15).WithMessage("Le téléphone fixe ne doit pas dépasser 15 caractères.");

        RuleFor(x => x.TelephonePortable)
            .NotEmpty().WithMessage("Le téléphone portable est requis.")
            .Matches(@"^(\+33|0)[6-7](\d{2}){4}$")
            .WithMessage("Le numéro de téléphone portable n'est pas valide. Format attendu : +33XXXXXXXXX ou 0XXXXXXXXX.")
            .MaximumLength(15).WithMessage("Le téléphone portable ne doit pas dépasser 15 caractères.");

        RuleFor(x => x.Email)
            .NotEmpty().WithMessage("L'email est requis.")
            .EmailAddress().WithMessage("L'email n'est pas valide.")
            .MaximumLength(50).WithMessage("L'email ne doit pas dépasser 50 caractères.");

        RuleFor(x => x.IdSite)
            .NotEmpty().WithMessage("L'ID du site est requis.");

        RuleFor(x => x.IdService)
            .NotEmpty().WithMessage("L'ID du service est requis.");
    }
}